@@ -7,7 +7,7 @@ use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(spawn receive msg snd wt snd_wt listener open_node);
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Carp;
 use EV;
@@ -19,7 +19,6 @@ use Storable qw(freeze thaw);
 my $DEBUG = 0;
 $DEBUG and require Data::Dumper;
 
-my $loop = EV::Loop->new();
 my @spawn            = ();
 my %msg              = ();
 my %fh2vpid          = ();
@@ -71,6 +70,7 @@ sub snd($$;@) {
 	$vpid = $self_parent_vpid if $vpid == 0;
 	$DEBUG and print "Send message '$msg' from $self_vpid to $vpid vpid in $self_vpid (\$\$=$$) with args: ", join(", ", @args), ".\n";
 	push @{$snd{$vpid}}, [$self_vpid, $vpid, $msg, \@args];
+	w_event_cb_reg($vpid);
 }
 
 
@@ -90,7 +90,7 @@ sub listener($$) {
 	my $sock = IO::Socket::INET->new(Proto => 'tcp', Blocking => 0, LocalHost => $host, LocalPort => $port, Listen => 20, ReuseAddr => 1);
 	if ($sock) {
 		$listener{$sock} = $sock;
-		$fh2rw{$sock} = $loop->io($sock, EV::READ, sub {
+		$fh2rw{$sock} = EV::io($sock, EV::READ, sub {
 			my $w = shift;
 			my $fh = $w->fh;
 			$DEBUG > 1 and print "Read event for listener from $self_vpid: \n";
@@ -101,7 +101,7 @@ sub listener($$) {
 			$fh2vpid{$sock}  = $vpid;
 			$vpid2fh{$vpid}  = $sock;
 			$fh2fh{$sock}    = $sock;
-			$fh2rw{$sock} = $loop->io($sock, EV::READ, \&r_event_cb);
+			$fh2rw{$sock} = EV::io($sock, EV::READ, \&r_event_cb);
 		});
 		return $sock;
 	} else {
@@ -125,7 +125,7 @@ sub open_node($$) {
 		$fh2vpid{$sock}  = $vpid;
 		$vpid2fh{$vpid}  = $sock;
 		$fh2fh{$sock}    = $sock;
-		$fh2rw{$sock} = $loop->io($sock, EV::READ, \&r_event_cb);
+		$fh2rw{$sock} = EV::io($sock, EV::READ, \&r_event_cb);
 		return $vpid;
 	} else {
 		carp "Cannot connect to socket '$host:$port' in $self_vpid: $!";
@@ -157,7 +157,7 @@ sub receive(&) {
 			}
 
 			close $_ foreach values %fh2fh, values %listener;
-			$loop = EV::Loop->new();
+			$_->stop foreach values %fh2rw, values %fh2ww;
 			@spawn    = ();
 			%listener = ();
 			%node     = ();
@@ -187,7 +187,7 @@ sub receive(&) {
 			$vpid2fh{$self_parent_vpid} = $self_parent_fh;
 			$fh2fh{$self_parent_fh}     = $self_parent_fh;
 
-			$fh2rw{$self_parent_fh} = $loop->io($self_parent_fh, EV::READ, \&r_event_cb);
+			$fh2rw{$self_parent_fh} = EV::io($self_parent_fh, EV::READ, \&r_event_cb);
 
 			$spawn->();
 
@@ -202,7 +202,7 @@ sub receive(&) {
 		$fh2vpid{$child} = $vpid;
 		$vpid2fh{$vpid}  = $child;
 		$fh2fh{$child}   = $child;
-		$fh2rw{$child} = $loop->io($child, EV::READ, \&r_event_cb);
+		$fh2rw{$child} = EV::io($child, EV::READ, \&r_event_cb);
 	}
 	@spawn = ();
 
@@ -215,7 +215,7 @@ sub receive(&) {
 	unless ($ipc_loop) {
 		$ipc_loop = 1;
 		w_event_cb_reg();
-		$loop->loop();
+		EV::loop;
 	}
 }
 
@@ -234,7 +234,7 @@ sub wt($$) {
 	}
 	$DEBUG and print "Start waiting for '$waited_vpid -> $waited_msg' in $self_vpid (\$\$=$$)\n";
 	w_event_cb_reg();
-	$loop->loop();
+	EV::loop;
 	my @rv = @waited_rv;
 	($waited_vpid, $waited_msg, @waited_rv) = ();
 	return wantarray ? @rv : $rv[0];
@@ -242,13 +242,14 @@ sub wt($$) {
 
 
 sub w_event_cb_reg {
+	my ($to_vpid) = @_;
 
-		foreach my $to (keys %snd) {
+		foreach my $to (defined $to_vpid ? $to_vpid : keys %snd) {
 			if (@{$snd{$to}}) {
 				my $fh = $vpid2fh{$to};
 				unless ($fh) {
 					if (@spawn) {
-						carp "Probably have forgotten to call receive.";
+						carp "Probably have forgotten to call receive." if not defined $to_vpid;
 						next;
 					} else {
 						if ($self_parent_fh) {
@@ -264,7 +265,7 @@ sub w_event_cb_reg {
 					my $buf = join "", pack("N", length $packet), $packet;
 					$w_bufs{$fh} = $buf;
 					$DEBUG and (@{$snd{$to}} or delete $snd{$to});
-					$fh2ww{$fh} = $loop->io($fh, EV::WRITE, \&w_event_cb);
+					$fh2ww{$fh} = EV::io($fh, EV::WRITE, \&w_event_cb);
 				}
 			}
 		}
@@ -358,12 +359,12 @@ sub r_event_cb {
 					splice @rcv, $i, 1;
 					$DEBUG and print "Stop waiting for '$waited_vpid -> $waited_msg' in $self_vpid (\$\$=$$)\n";
 					@waited_rv = @$args;
-					$loop->unloop();
+					EV::unloop();
 					return;
 				}
 			}
 			unless (exists $vpid2fh{$waited_vpid}) {
-				$loop->unloop();
+				EV::unloop();
 				return;
 			}			
 		} else {
